<?php

namespace Drupal\Tests\wordfilter\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Contains the appliance tests regarding Wordfilter configurations.
 *
 * @package Drupal\Tests\wordfilter\Functional
 * @group filter
 */
class WordfilterApplianceTest extends BrowserTestBase  {
  public static $modules = ['wordfilter'];

  protected $profile = 'standard';

  protected $user = NULL;

  /**
   * @see ::nodeInstance().
   */
  protected $node = NULL;

  protected function setUp() {
    parent::setUp();

    $this->user = $this->drupalCreateUser(['administer filters', 'administer nodes']);
    $this->node = $this->nodeInstance();
  }

  /**
   * Tests the appliance of Wordfilter configurations on content.
   */
  public function testApplianceOnContent() {
    $this->drupalLogin($this->user);

    $this->createWordfilterConfig();

    $this->addWordfilterConfigToBasicHTMLFormat();

    $this->viewNodeWithFilteredText();
  }

  /**
   * Helper function to test the creation of a Wordfilter configuration.
   */
  protected function createWordfilterConfig() {
    $this->drupalGet('admin/config/wordfilter_configuration/add');
    $this->assertSession()->statusCodeEquals(200);

    $this->submitForm([
      'id' => 'my_superduper_wordfilter_config',
      'label' => 'My superduper Wordfilter config',
      'substitute' => '***',
      'filter_words' => 'Lorem, Ipsum, Dolor'
    ], t('Save'));

    $this->assertSession()->responseContains(
      t('Created the %label Wordfilter configuration.',
        ['%label' => 'My superduper Wordfilter config']
      )
    );
  }

  /**
   * Helper function to test the addition of the Wordfilter configuration
   * to the Basic HTML format, which is included in the Standard profile.
   */
  protected function addWordfilterConfigToBasicHTMLFormat() {
    $this->drupalGet('admin/config/content/formats/manage/basic_html');
    $this->assertSession()->statusCodeEquals(200);

    $this->submitForm([
      'filters[wordfilter][status]' => TRUE,
      'filters[wordfilter][settings][active_wordfilter_configs][]' => ['my_superduper_wordfilter_config'],
    ], t('Save configuration'));

    $this->assertSession()->responseContains(
      t('The text format %format has been updated.', ['%format' => 'Basic HTML',]));
  }

  protected function viewNodeWithFilteredText() {
    $this->drupalGet('node/' . $this->nodeInstance()->id());
    $this->assertSession()->pageTextContains("*** *** *** Sit Amet");
  }

  /**
   * Create and get a node instance for all appliance tests.
   *
   * @return \Drupal\node\NodeInterface
   */
  protected function nodeInstance() {
    if (!isset($this->node)) {
      $this->node = $this->createNode([
        'type' => 'article',
        'title' => 'The Lorem Ipsum Node',
        'status' => 1,
        'body' => [
          [
            'value' => 'Lorem Ipsum Dolor Sit Amet',
            'format' => 'basic_html'
          ]
        ],
      ]);
    }

    return $this->node;
  }
}