<?php

namespace Drupal\Tests\wordfilter\Unit;

use \Drupal\Tests\UnitTestCase;
use \Drupal\wordfilter\Plugin\Filter\WordFilter;
use \Drupal\wordfilter\Entity\WordfilterConfiguration;

/**
 * @coversDefaultClass \Drupal\wordfilter\Plugin\Filter\WordFilter
 * @group filter
 */
class WordFilterTest extends UnitTestCase {

  /**
   * @var \Drupal\wordfilter\Plugin\Filter\WordFilter
   */
  protected $filter;

  /**
   * {@inheritdoc}
   */
  protected function setUp() {
    parent::setUp();
    $configuration['settings'] = [
      'active_wordfilter_configs' => ['my_superduper_wordfilter_configuration'],
    ];
    $this->filter = new WordFilter($configuration, 'wordfilter', ['provider' => 'test']);
    $this->filter->setStringTranslation($this->getStringTranslationStub());
  }

  /**
   * @covers ::filterWords
   *
   * @dataProvider providerFilterWords
   *
   * @param $text
   *   An unfiltered string with words.
   * @param $expected
   *   The expected output string.
   */
  public function testfilterWords($text, $expected) {
    $wordfilter_config = new WordfilterConfiguration([
      'id' => 'my_superduper_wordfilter_configuration',
      'label' => 'My superduper Wordfilter configuration'],
      'wordfilter_configuration');
    $wordfilter_config->setFilterWords(['Dolor', 'Amet']);
    $wordfilter_config->setSubstitute('***');

    $this->assertSame($expected, $this->filter->filterWords($text, $wordfilter_config));
  }

  /**
   * Data provider for testfilterWords().
   *
   * TODO Add more reasonable data sets.
   *
   * @return array
   */
  public function providerFilterWords() {
    return [
      ['Lorem Ipsum Dolor Sit Amet', 'Lorem Ipsum *** Sit ***'],
      ['lorem ipsum dolor sit amet', 'lorem ipsum *** sit ***'],
      ['LoremIpsumDolorSitAmet', 'LoremIpsumDolorSitAmet']
    ];
  }
}